import 'dart:convert';
import 'package:flutter_test/flutter_test.dart';

import 'package:odds_account_sdk/client.dart';

void main() async {
  final birthdate = DateTime.utc(2022, 6, 22, 14, 55, 0);
  final address = Address("CN", "ZJ", "HZ", "CangQian");
  final account = Account(
    '00001',
    'bob',
    '123456',
    'bob@example.com',
    'bob',
    'given',
    'family',
    'middle',
    'avatar.png',
    Gender.unknown,
    birthdate,
    address,
  );

  OddsAccountClient client = OddsAccountClient.authing(
      '62b51f95688cd8c27d2b328e', '62b5309cbfdfbcdaa19d7acb');
  await Future.delayed(const Duration(seconds: 1));

  test('serialize account to json', () {
    final json = jsonEncode(account);

    expect(
        json,
        allOf(
            contains('"user_id":"00001"'),
            contains('"gender":"U"'),
            contains('"birthdate":"2022-06-22T14:55:00.000Z"'),
            contains('"country":"CN"')));
  });

  test('serialize result to json', () {
    final success = Result.success(account);
    final successJson = jsonEncode(success);

    expect(
        successJson,
        allOf(
          contains('"code":200'),
          contains('"message":""'),
          contains('"user_id":"00001"'),
        ));

    final failure = Result.failure(StatusCode.notFound, "User not exists");
    final failureJson = jsonEncode(failure);
    expect(
        failureJson,
        allOf(
          contains('"code":404'),
          contains('"message":"User not exists"'),
        ));
  });

  test('login by username and password', () async {
    final r1 = await client.loginByPassword("test", "incorrect password");
    expect(r1.isSuccess(), false);

    final r2 = await client.loginByPassword("test", "OLt4C34aRvHBP4ITPlcf");
    expect(r2.isSuccess(), true);
  });
}
